pub struct CreateFeedDocumentResult {
pub feed_document_id: String,
pub url: String,
pub encryption_details: Box<FeedDocumentEncryptionDetails>,
}Expand description
CreateFeedDocumentResult : Information required to encrypt and upload a feed document’s contents.
Fields
feed_document_id: StringThe identifier of the feed document.
url: StringThe presigned URL for uploading the feed contents. This URL expires after 5 minutes.
encryption_details: Box<FeedDocumentEncryptionDetails>Implementations
sourceimpl CreateFeedDocumentResult
impl CreateFeedDocumentResult
sourcepub fn new(
feed_document_id: String,
url: String,
encryption_details: FeedDocumentEncryptionDetails
) -> CreateFeedDocumentResult
pub fn new(
feed_document_id: String,
url: String,
encryption_details: FeedDocumentEncryptionDetails
) -> CreateFeedDocumentResult
Information required to encrypt and upload a feed document’s contents.